pub struct WriteGuard<V> { /* private fields */ }Expand description
Allows access to the data contained within just like a mutex guard.
Implementations
Sourceimpl<V> WriteGuard<V>
impl<V> WriteGuard<V>
Sourcepub fn release_event(guard: &WriteGuard<V>) -> Option<&Event>
pub fn release_event(guard: &WriteGuard<V>) -> Option<&Event>
Returns a reference to the event previously set using
create_release_event on the FutureGuard which preceded this
WriteGuard. The event can be manually ‘triggered’ by calling
...set_complete()... or used normally (as a wait event) by
subsequent commands. If the event is not manually completed it will be
automatically set complete when this WriteGuard is dropped.
Sourcepub fn release(guard: WriteGuard<V>) -> OrderLock<V>
pub fn release(guard: WriteGuard<V>) -> OrderLock<V>
Triggers the release event and releases the lock held by this WriteGuard
before returning the original OrderLock.